//******************************************************************************
//
//                      PIC KICK TWEET Demonstration
//
//******************************************************************************
// FileName:        main.c
// Microcontroller: PIC18F4520
// Compiler:        C18
// Target Hardware: PIC KICK Development Board
// Company:         ENTESLA
//
//  Author              Date            Comment
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  WebWarrior          13/12/11        Original
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//                          Description                     
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// The firmware reads the tweet sent over uart by the desktop application and 
// displays the tweet on the CLCD.
// Note: Every tweet must be terminated with a '#' character
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Configuration Bit Settings:Set in Code
//
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//                 Hardware Settings for PIC KICK
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  Microcontroller: PIC18f4520
//  Ext.Oscillator:  12 MHz
//  Jumper Setting:  None
//
//  PINOUT:          LCD   -   PIC 		USB-UART    -   PIC
//		     ------------- 		-------------------
//		     DB4   -   RD4		RX          -   TX
//		     DB5   -   RD5 		TX          -   RX
//		     DB6   -   RD6
//	             DB7   -   RD7
//		     RS    -   RB2
//		     E     -   RB4
//	             R/W   -   GND
//******************************************************************************

//*******INCLUDES***************************************************************
#include "config.h"
//****End of INCLUDES***********************************************************

// Comment the below line to avoid over writing the on-chip bootloader's 
// configuration bit setting.
#pragma config WDT = OFF, XINST = OFF, LVP = OFF, OSC = HS

void _DelayMs(unsigned int delay);
 
//******************************************************************************
// Function:        void main(void)
//
// Input:           None
//
// Output:          None
//
// Overview:        Main program entry point.
//
// Note:            None
//******************************************************************************
void main(void)
{
    unsigned char tweetFeed[17]={0};
    unsigned char i=0,count,temp=0;
   
    UartInit();
    ClcdInit();
    ClcdInit();
    ClcdCursorOff();
    ClcdClear();

    ClcdGoto(1,1);
    ClcdPutS_P("    PIC KICK    ");
    ClcdGoto(1,2);
    ClcdPutS_P("      TWEET     ");

    _DelayMs(1500);
	
    while(1)
    {
        //wait until tweet terminator '#' is recieved
        while( (tweetFeed[i++]=UartGetCh()) != '#');	
        temp=i-1;   //String length excluding the '#' character

        ClcdClear();
        ClcdGoto(1,1);

        //Retrieving the characters in the string and displaying on CLCD
        for(count=0;count<temp;count++)
        {
            i=0;
            ClcdPutCh(tweetFeed[count]);
            tweetFeed[count]=0; //clearing the array element immediately
        }

    }
}

//******************************************************************************
//  Function:       void _DelayMs(unsigned int delay)
//
//  Input:          Required Delay in milliseconds
//
//  Output:         None.
//
//  Overview:       Generates a delay of specified amount.
//
//  Note:           None
//******************************************************************************
void _DelayMs(unsigned int delay)
{
    volatile unsigned long j;
    volatile unsigned char i;
    
    j=delay*PROC_FREQ_MHz;
    while(j--)  
    {
        for(i=0;i<18;i++); 
    }
}
