//******************************************************************************
//
//                  UART Interface Library (Header File)
//
//******************************************************************************
//  FileName:           uart.h
//  Microcontroller:    PIC18F4520
//  Compiler:           C18
//  Target Hardware:    PIC KICK Development Board
//  Company:            ENTESLA
//  Website:            www.entesla.com
//  Email:              feedbackATenteslaDOTcom
//
//  Author              Date            Comment
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  WebWarrior          09/04/10        Original
//  dRaGoNRaCeR         27/07/10        Revision-I
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//                          Function Overview
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  UartInit();
//  Initializes UART Interface. Use this function before using other UART 
//  functions.
//
//  UartPutCh('a');
//  Transmits the input character on UART.
//
//  void UartPutS(string);
//  Transmits the input character string variable on UART.
//
//  UartPutS_P(string);
//  Transmits the input string(stored in program memory) on UART.
//
//  UartGetCh();
//  Returns the character recieved on the UART.
//******************************************************************************

#ifndef UART_H
#define UART_H
    
    //*****USER SETTINGS************    
    #define BAUDRATE            9600    //BaudRate
    //***End of USER SETTINGS*******
    
    #if(BAUDRATE>9600)
        #define BAUD_CONFIG_BYTE (unsigned int)((((unsigned long)PROC_FREQ/BAUDRATE)/16)-1)
        #define BRGH_SET_CLEAR (TXSTA|0x04)//set the BRGH bit
    #else
        #define BAUD_CONFIG_BYTE (unsigned int)((((unsigned long)PROC_FREQ/BAUDRATE)/64)-1)
        #define BRGH_SET_CLEAR (TXSTA&(~0x04))//clearing the BRGH bit
    #endif
    
	//*******Public Protoype//*********
	void UartInit(void);
	void UartPutCh(char character);
	void UartPutS(void *str);
	void UartPutS_P(const rom char *string);
	unsigned char UartGetCh(void);
	//*****End of Public Protoype//*****
	
#endif //UART_H